@@ -10,16 +10,15 @@ use Scalar::Util qw( looks_like_number );
 
 require Exporter;
 
-
 # There is much debate on whether to use base, parent, or manipulate @ISA.
 # The lowest common denominator is what belongs in modules, we'll do @ISA.
 
 our @ISA       = qw(Exporter);    ## no critic (ISA)
 our @EXPORT_OK = qw(
-    bsearch_str       bsearch_str_pos     bsearch_str_range
-    bsearch_num       bsearch_num_pos     bsearch_num_range
-    bsearch_custom    bsearch_custom_pos
-    bsearch_transform
+  bsearch_str       bsearch_str_pos     bsearch_str_range
+  bsearch_num       bsearch_num_pos     bsearch_num_range
+  bsearch_custom    bsearch_custom_pos
+  bsearch_transform
 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
@@ -28,7 +27,7 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 ## no critic (prototypes)
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Needed for developer's releases: See perlmodstyle.
 # $VERSION = eval $VERSION;    ## no critic (eval,version)
@@ -55,7 +54,7 @@ sub bsearch_str ($\@) {
     }
 
     return $min
-        if $max == $min && $target eq $aref->[$min];
+      if $max == $min && $target eq $aref->[$min];
 
     return;
 }
@@ -76,7 +75,7 @@ sub bsearch_num ($\@) {
         }
     }
     return $min
-        if $max == $min && $target == $aref->[$min];
+      if $max == $min && $target == $aref->[$min];
     return;    # Undef in scalar context, empty list in list context.
 }
 
@@ -97,7 +96,7 @@ sub bsearch_custom (&$\@) {
     }
 
     return $min
-        if $max == $min && $code->( $target, $aref->[$min] ) == 0;
+      if $max == $min && $code->( $target, $aref->[$min] ) == 0;
 
     return;    # Undef in scalar context, empty list in list context.
 }
@@ -120,7 +119,7 @@ sub bsearch_transform (&$\@) {
             }
         }
         return $min
-            if $max == $min && $target == $transform_code->( $aref->[$min] );
+          if $max == $min && $target == $transform_code->( $aref->[$min] );
     }
     else {
         while ( $max > $min ) {
@@ -133,7 +132,7 @@ sub bsearch_transform (&$\@) {
             }
         }
         return $min
-            if $max == $min && $target eq $transform_code->( $aref->[$min] );
+          if $max == $min && $target eq $transform_code->( $aref->[$min] );
     }
 
     return;    # Undef in scalar context, empty list in list context.
@@ -201,7 +200,7 @@ sub bsearch_str_range ($$\@) {
     my ( $low_target, $high_target, $aref ) = @_;
     my $index_low  = bsearch_str_pos( $low_target,  @{$aref} );
     my $index_high = bsearch_str_pos( $high_target, @{$aref} );
-    if (   $index_high == @{$aref}
+    if (   $index_high == scalar @{$aref}
         or $aref->[$index_high] gt $high_target )
     {
         $index_high--;
@@ -213,7 +212,7 @@ sub bsearch_num_range ($$\@) {
     my ( $low_target, $high_target, $aref ) = @_;
     my $index_low  = bsearch_num_pos( $low_target,  @{$aref} );
     my $index_high = bsearch_num_pos( $high_target, @{$aref} );
-    if (   $index_high == @{$aref}
+    if (   $index_high == scalar @{$aref}
         or $aref->[$index_high] > $high_target )
     {
         $index_high--;
@@ -231,10 +230,7 @@ List::BinarySearch - Binary Search a sorted list or array.
 
 =head1 VERSION
 
-Version 0.07
-
-New function: bsearch_custom_pos.
-
+Version 0.09
 
 =head1 SYNOPSIS
 
